# Data Structure and in Algorithms in Python 

A Python package of data structure codes

## Usage

This package contains some common ready to use Data Structure and Algorithm implementations. The primary focus is provide pre-coded functions used in various Data Structures and Algorithm problems.

-----------------------------------
Note: This package is developed and maintained by a student. Please don't mind the mistakes :)
